==> curatedTCGAData_1.18.0.tar.gz: curatedTCGAData/inst/doc/curatedTCGAData.R <==
## ---- eval=FALSE--------------------------------------------------------------
#  if (!requireNamespace("BiocManager", quietly = TRUE))
#      install.packages("BiocManager")
#  
#  BiocManager::install("curatedTCGAData")

## ----include=TRUE,results="hide",message=FALSE,warning=FALSE------------------
library(curatedTCGAData)
library(MultiAssayExperiment)
library(TCGAutils)

## -----------------------------------------------------------------------------
head(
    curatedTCGAData(
        diseaseCode = "COAD", assays = "*", version = "1.1.38"
    )
)

## -----------------------------------------------------------------------------
data('diseaseCodes', package = "TCGAutils")
head(diseaseCodes)

## ----eval=FALSE---------------------------------------------------------------
#  curatedTCGAData(
#      diseaseCode = "*", assays = "*", version = "2.0.1"
#  )

## -----------------------------------------------------------------------------
head(
    curatedTCGAData(
        diseaseCode = "COAD", assays = "*", version = "2.0.1"
    )
)

## ---- message=FALSE-----------------------------------------------------------
(accmae <- curatedTCGAData(
    "ACC", c("CN*", "Mutation"), version = "2.0.1", dry.run = FALSE
))

## -----------------------------------------------------------------------------
head(getSubtypeMap(accmae))

## -----------------------------------------------------------------------------
head(getClinicalNames("ACC"))

colData(accmae)[, getClinicalNames("ACC")][1:5, 1:5]

## -----------------------------------------------------------------------------
sampleTables(accmae)

## -----------------------------------------------------------------------------
data(sampleTypes, package = "TCGAutils")
head(sampleTypes)

## -----------------------------------------------------------------------------
sampleTypes[sampleTypes[["Code"]] %in% c("01", "10"), ]

splitAssays(accmae, c("01", "10"))

## -----------------------------------------------------------------------------
tums <- TCGAsampleSelect(colnames(accmae), "01")

## -----------------------------------------------------------------------------
(primaryTumors <- TCGAprimaryTumors(accmae))

## -----------------------------------------------------------------------------
sampleTables(primaryTumors)

## -----------------------------------------------------------------------------
(accmut <- getWithColData(accmae, "ACC_Mutation-20160128", mode = "append"))
head(colData(accmut)[, 1:4])

## -----------------------------------------------------------------------------
ragex <- accmae[["ACC_Mutation-20160128"]]
## convert score to numeric
mcols(ragex)$Entrez_Gene_Id <- as.numeric(mcols(ragex)[["Entrez_Gene_Id"]])
sparseAssay(ragex, i = "Entrez_Gene_Id", sparse=TRUE)[1:6, 1:3]

## -----------------------------------------------------------------------------
as(ragex, "GRangesList")

## -----------------------------------------------------------------------------
td <- tempdir()
tempd <- file.path(td, "ACCMAE")
if (!dir.exists(tempd))
    dir.create(tempd)

exportClass(accmae, dir = tempd, fmt = "csv", ext = ".csv")

## -----------------------------------------------------------------------------
sessionInfo()

==> curatedTCGAData_1.22.2.tar.gz: curatedTCGAData/inst/doc/curatedTCGAData.R <==
## ---- eval=FALSE--------------------------------------------------------------
#  if (!requireNamespace("BiocManager", quietly = TRUE))
#      install.packages("BiocManager")
#  
#  BiocManager::install("curatedTCGAData")

## ----include=TRUE,results="hide",message=FALSE,warning=FALSE------------------
library(curatedTCGAData)
library(MultiAssayExperiment)
library(TCGAutils)

## -----------------------------------------------------------------------------
head(
    curatedTCGAData(
        diseaseCode = "COAD", assays = "*", version = "1.1.38"
    )
)

## -----------------------------------------------------------------------------
data('diseaseCodes', package = "TCGAutils")
head(diseaseCodes)

## ----eval=FALSE---------------------------------------------------------------
#  curatedTCGAData(
#      diseaseCode = "*", assays = "*", version = "2.0.1"
#  )

## -----------------------------------------------------------------------------
head(
    curatedTCGAData(
        diseaseCode = "COAD", assays = "*", version = "2.0.1"
    )
)

## ---- message=FALSE-----------------------------------------------------------
(accmae <- curatedTCGAData(
    "ACC", c("CN*", "Mutation"), version = "2.0.1", dry.run = FALSE
))

## -----------------------------------------------------------------------------
head(getSubtypeMap(accmae))

## -----------------------------------------------------------------------------
head(getClinicalNames("ACC"))

colData(accmae)[, getClinicalNames("ACC")][1:5, 1:5]

## -----------------------------------------------------------------------------
sampleTables(accmae)

## -----------------------------------------------------------------------------
data(sampleTypes, package = "TCGAutils")
head(sampleTypes)

## -----------------------------------------------------------------------------
sampleTypes[sampleTypes[["Code"]] %in% c("01", "10"), ]

TCGAsplitAssays(accmae, c("01", "10"))

## -----------------------------------------------------------------------------
tums <- TCGAsampleSelect(colnames(accmae), "01")

## -----------------------------------------------------------------------------
(primaryTumors <- TCGAprimaryTumors(accmae))

## -----------------------------------------------------------------------------
sampleTables(primaryTumors)

## -----------------------------------------------------------------------------
(accmut <- getWithColData(accmae, "ACC_Mutation-20160128", mode = "append"))
head(colData(accmut)[, 1:4])

## -----------------------------------------------------------------------------
ragex <- accmae[["ACC_Mutation-20160128"]]
## convert score to numeric
mcols(ragex)$Entrez_Gene_Id <- as.numeric(mcols(ragex)[["Entrez_Gene_Id"]])
sparseAssay(ragex, i = "Entrez_Gene_Id", sparse=TRUE)[1:6, 1:3]

## -----------------------------------------------------------------------------
as(ragex, "GRangesList")

## -----------------------------------------------------------------------------
td <- tempdir()
tempd <- file.path(td, "ACCMAE")
if (!dir.exists(tempd))
    dir.create(tempd)

exportClass(accmae, dir = tempd, fmt = "csv", ext = ".csv")

## -----------------------------------------------------------------------------
sessionInfo()
